﻿using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using Microsoft.SharePoint;
using RH.Warmup.Web.UI;

namespace RH.Warmup.Helper
{
	public static class Extensions
	{
		public static T1 GetValue<T, T1>(this WebControl control) where T : WebControl
		{
			switch (typeof(T).Name)
			{
				case "TextBox":
					return (T1)(object)((TextBox)control).Text;
				case "CheckBox":
					return (T1)(object)((CheckBox)control).Checked;
				case "TimePicker":
					return (T1)(object)((TimePicker)control).Value;
				case "DropDownList":
					return (T1)(object)((DropDownList)control).SelectedValue;
				default:
					return default(T1);
			}
		}

		/// <summary>
		/// Update or Insert the CachKey
		/// </summary>
		/// <param name="context"></param>
		/// <param name="value"></param>
		/// <param name="cacheKey"></param>
		public static void UpdateOrInsertCache(this System.Web.HttpContext context, string cacheKey, string value)
		{
			if (!context.Items.Contains(cacheKey))
			{
				context.Items.Add(cacheKey, value);
			}
			else
			{
				context.Items[cacheKey] = value;
			}
		}

		/// <summary>
		/// Get from cache, or return default value of T
		/// </summary>
		/// <typeparam name="T"></typeparam>
		/// <param name="context"></param>
		/// <param name="cacheKey"></param>
		/// <returns></returns>
		public static T GetFromCache<T>(this System.Web.HttpContext context, string cacheKey)
		{
			if (!context.Items.Contains(cacheKey))
				return default(T);

			if (typeof(T).FullName == typeof(int).FullName)
			{
				return (T)(object)int.Parse((string)context.Items[cacheKey]);
			}
			throw new NotImplementedException("Type '" + typeof(T).FullName + "' is not implemented");
		}
	}
}
