﻿using System.Diagnostics;
using System.Security;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Utilities;

namespace RH.Warmup
{
	/// <summary>
	/// Read Ressource values
	/// </summary>
	public class LocalizationHelper
	{
		/// <summary>
		/// The default resource filename
		/// </summary>
		private const string ResourceFile = "RH.Warmup";

		/// <summary>
		/// Get a Resource value
		/// </summary>
		/// <param name="resourceKey">e.g. Navigation.Global.Homepage</param>
		/// <returns>The <see cref="string"/>the localized string</returns>
		[DebuggerStepThrough]
		public static string GetString(string resourceKey)
		{
			return GetString(resourceKey, ResourceFile);
		}

		/// <summary>
		/// Get a Resource value
		/// </summary>
		/// <param name="resourceKey">e.g. Navigation.Global.Homepage </param>
		/// <param name="resourceFilename">e.g. "BDI.Collaboration" or "core"</param>
		/// <returns>The <see cref="string"/>the localized string</returns>
		public static string GetString(string resourceKey, string resourceFilename)
		{
			try
			{
				// get lcid from context web, or use default, which is german
				var lcid = SPContext.Current != null && SPContext.Current.Web != null ? SPContext.Current.Web.Language : 1031;

				var localizedString = SPUtility.GetLocalizedString("$Resources:" + resourceKey, resourceFilename, lcid);
				if (localizedString.StartsWith("$Resources:"))
				{
					// could not find resource key
					Trace.WriteLine("Could not find a Resource with key '" + resourceKey + "' in Resource file '" + resourceFilename + "'");
					return resourceKey;
				}

				return localizedString;
			}
			catch (SecurityException ex)
			{
				// may occure during provisioning
				Trace.WriteLine(ex.ToString());
				return resourceKey;
			}
		}
	}
}
