﻿using System;
using System.Data;
using System.Net;

namespace RH.Warmup.Update
{
	public class Updates
	{
		private readonly string _assembly;
		private readonly string _feedUrl;
		private readonly string _errorText;

		/// <summary>
		/// create updates class with an assemblyname
		/// </summary>
		/// <param name="assembly"></param>
		/// <param name="errorText"> </param>
		public Updates(string assembly, string errorText)
		{
			_assembly = assembly;
			_errorText = errorText;
			_feedUrl = "http://www.hezser.de/_layouts/listfeed.aspx?List=%7BBD1D3115%2DF71B%2D4A5E%2D8A42%2DF8CEB00C9869%7D";
		}

		public Updates(string assembly, string feedUrl, string errorText)
		{
			_assembly = assembly;
			_feedUrl = feedUrl;
			_errorText = errorText;
		}

		/// <summary>
		/// find lates version from rss feed
		/// </summary>
		/// <returns></returns>
		public LatestVersion GetLatestVersion()
		{
			try
			{
				WebRequest request = WebRequest.Create(_feedUrl);
				request.Timeout = 1000;
				using (WebResponse response = request.GetResponse())
				{
					var ds = new DataSet();
					ds.ReadXml(response.GetResponseStream(), XmlReadMode.Auto);

					DataTable dt = ds.Tables["item"];
					foreach (DataRow row in dt.Rows)
					{
						if (Convert.ToString(row["title"]) != _assembly)
							continue;

						// we found our assembly
						string description = Convert.ToString(row["description"]);
						DateTime publishDate = Convert.ToDateTime(row["pubDate"]);

						return new LatestVersion(description, publishDate, _errorText);
					}
				}
				return new LatestVersion("No Versioninformation found.");
			}
			catch (WebException ex)
			{
				if (ex.Status == WebExceptionStatus.Timeout)
					return new LatestVersion("0.0.0.0", DateTime.MinValue, string.Empty);

				return new LatestVersion(ex.Message);
			}
			catch (Exception ex)
			{
				return new LatestVersion(ex.Message);
			}
		}
	}
}