﻿using System;
using System.Globalization;
using System.Linq;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using WarmupSharePoint;

namespace RH.Warmup.Web.UI
{
	public class WarmupSettingsItemTemplate : ITemplate
	{
		private HtmlTableRow _row;
		private Guid _webApplicationId;
		private CheckBox _activate;
		private Label _name;
		private TimePicker _time;
		private DropDownList _schedule;
		private CheckBox _searchWarmup;
		private TextBox _searchKeyword;
		private CheckBox _eventlog;

		/// <summary>
		/// Add CSS for alternating TR
		/// </summary>
		public bool Alternating { get; set; }

		/// <summary>
		/// Number all all rows within the Repeater
		/// </summary>
		public int RowCount { get; set; }

		public void InstantiateIn(Control container)
		{
			_row = new HtmlTableRow();
			_row.DataBinding += _row_DataBinding;
			container.Controls.Add(_row);

			var cell = CreateCell(null);
			_row.Cells.Add(cell);
			_activate = new CheckBox { ID = "ActivateWarmup" };
			_activate.DataBinding += _checkBox_DataBinding;
			cell.Controls.Add(_activate);

			cell = CreateCell("WebApplicationName");
			_row.Cells.Add(cell);
			_name = new Label { ID = "WebApplicationName" };
			_name.Style.Add(HtmlTextWriterStyle.WhiteSpace, "nowrap");
			_name.DataBinding += _name_DataBinding;
			cell.Controls.Add(_name);

			cell = CreateCell(null);
			_row.Cells.Add(cell);
			_time = new TimePicker { ID = "WarmupTime", ControlCount = RowCount };
			_time.Style.Add(HtmlTextWriterStyle.Width, "100%");
			_time.DataBinding += _time_DataBinding;
			cell.Controls.Add(_time);
			cell.Controls.Add(new LiteralControl("<br/>"));
			_schedule = new DropDownList { ID = "WarmupSchedule" };
			_schedule.DataBinding += _schedule_DataBinding;
			_schedule.Items.Add(new ListItem(LocalizationHelper.GetString("Schedule_Hourly"), "1"));
			_schedule.Items.Add(new ListItem(LocalizationHelper.GetString("Schedule_Daily"), "24"));
			cell.Controls.Add(_schedule);

			cell = CreateCell(null);
			cell.Style.Add(HtmlTextWriterStyle.TextAlign, "center");
			_row.Cells.Add(cell);
			_searchWarmup = new CheckBox { ID = "SearchWarmup" };
			_searchWarmup.DataBinding += _checkBox_DataBinding;
			cell.Controls.Add(_searchWarmup);

			cell = CreateCell(null);
			_row.Cells.Add(cell);
			_searchKeyword = new TextBox { ID = "SearchKeyword" };
			_searchKeyword.DataBinding += _searchKeyword_DataBinding;
			cell.Controls.Add(_searchKeyword);

			cell = CreateCell(null);
			_row.Cells.Add(cell);
			cell.Style.Add(HtmlTextWriterStyle.TextAlign, "center");
			_eventlog = new CheckBox { ID = "Eventlog" };
			_eventlog.DataBinding += _checkBox_DataBinding;
			cell.Controls.Add(_eventlog);
		}

		private HtmlTableCell CreateCell(string additionalClass)
		{
			var cell = new HtmlTableCell();

			var additional = string.IsNullOrEmpty(additionalClass) ? string.Empty : " " + additionalClass;

			if (Alternating) cell.Attributes.Add("class", "ms-vb2 ms-featurealtrow" + additional);
			else cell.Attributes.Add("class", "ms-vb2" + additional);

			return cell;
		}

		/// <summary>
		/// write WebApplicationID to data-webapplication attribute
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		void _row_DataBinding(object sender, EventArgs e)
		{
			var row = sender as HtmlTableRow;
			var repItem = row.NamingContainer as RepeaterItem;
			var item = (Setting)repItem.DataItem;
			_webApplicationId = item.WebApplicationId;
			row.Attributes.Add("data-webapplicationid", item.WebApplicationId.ToString());

			if (item.TimerJobId != Guid.Empty)
				row.Attributes.Add("data-timerjobid", item.TimerJobId.ToString());
		}

		void _checkBox_DataBinding(object sender, EventArgs e)
		{
			var checkBox = sender as CheckBox;
			try
			{
				var repItem = checkBox.NamingContainer as RepeaterItem;
				var item = (Setting)repItem.DataItem;
				switch (checkBox.ID)
				{
					case "ActivateWarmup":
						checkBox.Checked = item.Activated;
						break;
					case "SearchWarmup":
						checkBox.Checked = item.WarmupSearch;
						break;
					case "Eventlog":
						checkBox.Checked = item.EventLog;
						break;
				}
			}
			catch (Exception ex)
			{
				checkBox.Text = ex.Message;
			}
		}

		private void _searchKeyword_DataBinding(object sender, EventArgs e)
		{
			var searchKeyword = sender as TextBox;
			try
			{
				var repItem = searchKeyword.NamingContainer as RepeaterItem;
				var item = (Setting)repItem.DataItem;
				searchKeyword.Text = item.QueryKeyword;
				if (string.IsNullOrEmpty(searchKeyword.Text))
					searchKeyword.Text = LocalizationHelper.GetString("ApplicationPage_Settings_SearchKeyword");
			}
			catch (Exception ex)
			{
				searchKeyword.Text = ex.Message;
			}
		}

		void _time_DataBinding(object sender, EventArgs e)
		{
			var time = sender as TimePicker;
			try
			{
				var repItem = time.NamingContainer as RepeaterItem;
				var item = (Setting)repItem.DataItem;
				if (item.Time != DateTime.MinValue)
				{
					time.Text = item.Time.ToString("t");
				}
				time.WebApplicationId = item.WebApplicationId;
			}
			catch (Exception ex)
			{
				time.Text = ex.Message;
			}
		}

		void _schedule_DataBinding(object sender, EventArgs e)
		{
			var schedule = sender as DropDownList;
			try
			{
				var repItem = schedule.NamingContainer as RepeaterItem;
				var item = (Setting)repItem.DataItem;
				// can assign only, if the value is available
				if (schedule.Items.Cast<ListItem>().Any(i => i.Value == item.Schedule.ToString()))
					schedule.SelectedValue = item.Schedule.ToString(CultureInfo.InvariantCulture);
			}
			catch (Exception ex)
			{
				schedule.Items.Insert(0, ex.Message);
			}
		}

		void _name_DataBinding(object sender, EventArgs e)
		{
			var name = sender as Label;
			try
			{
				var repItem = name.NamingContainer as RepeaterItem;
				var item = (Setting)repItem.DataItem;
				name.Text = item.Name;
			}
			catch (Exception ex)
			{
				name.Text = ex.Message;
			}
		}

		internal Setting GetSettingsForWebApplication()
		{
			var setting = new Setting
			{
				WebApplicationId = _webApplicationId,
				WarmupSearch = _searchWarmup.Checked,
				QueryKeyword = _searchKeyword.Text,
				EventLog = _eventlog.Checked,
				Time = _time.Value,
				Schedule = int.Parse(_schedule.SelectedValue)
			};
			return setting;
		}
	}
}
