﻿using System;
using System.Data;
using System.Diagnostics;
using System.Linq;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Administration;
using Microsoft.SharePoint.Search.Query;
using Microsoft.SharePoint.Utilities;

namespace WarmupSharePoint.Helper
{
	public class SharePointHelper
	{
		/*
				internal static int GetWebsCountFromWebApplication(string webApplicationUrl)
				{
					//var ssaProxy = (SearchServiceApplicationProxy)SearchServiceApplicationProxy.GetProxy(SPServiceContext.GetContext(SPContext.Current.Site));
					var keywordQuery = new KeywordQuery(webApplicationUrl)
					{
						RowLimit = 200,
						TrimDuplicates = false,
						//ResultsProvider = SearchProvider.Default
					};
					keywordQuery.SelectProperties.Clear();
					keywordQuery.SelectProperties.Add("Path");
					keywordQuery.ResultTypes |= ResultType.RelevantResults;
					keywordQuery.QueryText = String.Format("contentclass:STS_Web AND path:{0}", webApplicationUrl);
					ResultTableCollection searchResults;
					try
					{
						searchResults = keywordQuery.Execute();
					}
					catch (Exception ex)
					{
						Trace.WriteLine(ex.ToString());
						//"Your query is malformed. Please rephrase your query."
						return -1;
					}

					if (!searchResults.Exists(ResultType.RelevantResults)) return 0;

					var searchResult = searchResults[ResultType.RelevantResults];
					var results = new DataTable { TableName = "SearchResults" };
					results.Load(searchResult, LoadOption.OverwriteChanges);
					return results.Rows.Count;
				}
		*/

		public static int GetWebsCountFromWebApplication(SPWebApplication webapplication)
		{
			using (new SPMonitoredScope("WarmupSharePoint.Helper.GetWebsCountFromWebApplication"))
			{
				int websCount = 0;
				foreach (SPSite site in webapplication.Sites)
				{
					try
					{
						site.CatchAccessDeniedException = false;
						websCount += site.AllWebs.Count;
					}
					catch (Exception ex)
					{
						Trace.WriteLine("Exception on site '" + site.Url + "': " + ex.Message);
					}
					finally
					{
						site.CatchAccessDeniedException = true;
						site.Dispose();
					}
				}

				return websCount;
			}
		}

		public static string[] GetAlternatUrlForWebApplication(SPWebApplication webApplication)
		{
			string[] iisUrls = (from iisSetting in webApplication.IisSettings
									  from alternateUrl in webApplication.AlternateUrls
									  where alternateUrl.UrlZone == iisSetting.Key
									  select alternateUrl.Uri.AbsoluteUri.TrimEnd('/')).ToArray();
			return iisUrls;
		}
	}
}
