﻿using System.IO;
using System.Net;
using System.Text.RegularExpressions;

namespace WarmupSharePoint.Helper
{
	internal class WebHelper
	{
		internal static string GetWebExceptionMessage(WebException ex)
		{
			switch (ex.Status)
			{
				case WebExceptionStatus.ConnectFailure:
					return "Connection Failure";
				case WebExceptionStatus.Timeout:
					return "Timeout";
				case WebExceptionStatus.NameResolutionFailure:
					return "Name resolution Failure";
				case WebExceptionStatus.ProtocolError:
				default:
					if (ex.Response != null)
					{
						using (var response = ex.Response as HttpWebResponse)
						{
							var message = response.StatusCode + " - ";
							using (Stream responseStream = response.GetResponseStream())
							using (var streamReader = new StreamReader(responseStream))
							{
								string responseHtml = streamReader.ReadToEnd();

								// extract title, which hopefully contains the error message
								var regex = new Regex("<title>(?<title>.*)</title>");
								if (regex.IsMatch(responseHtml))
								{
									return message + regex.Match(responseHtml).Groups["title"].Value;
								}
								return message + responseHtml;
							}
						}
					}

					return "An unknown Error occured";
			}
		}
	}
}
